@@ -154,6 +154,14 @@ class interface(abstract_instrument_interface.abstract_interface):
         self.settings['step_size'] = step_size
         self.gui.edit_StepSize.setText(f"{self.settings['step_size']:.4f}")
         return True
+    
+    def home(self):
+        self.logger.info(f"Homing device...")
+        self.gui.set_moving_state()
+        self.instrument.move_home()
+        #Start checking periodically the value of self.instrument.is_in_motion. It it's true, we read current
+        #position and update it in the GUI. When it becomes False, call self.end_movement
+        self.check_property_until(self.instrument,pyThorlabsAPT.is_in_motion,[True,False],[[self.read_position],[self.end_movement]])
 
     def move_single_step(self,direction,step_size = None):
         if step_size == None:
@@ -162,13 +170,14 @@ class interface(abstract_instrument_interface.abstract_interface):
         self.logger.info(f"Will move by {movement}. Begin moving...")
         self.instrument.move_by(movement)
         self.gui.set_moving_state()
-        #Start checking periodically the value of self.instrument.is_in_motion/. When it becomes False, call self.end_movement
-        self.check_property_until(self.instrument,pyThorlabsAPT.is_in_motion,[False],[[self.end_movement]])
+        #Start checking periodically the value of self.instrument.is_in_motion. It it's true, we read current
+        #position and update it in the GUI. When it becomes False, call self.end_movement
+        self.check_property_until(self.instrument,pyThorlabsAPT.is_in_motion,[True,False],[[self.read_position],[self.end_movement]])
         
     def end_movement(self):
         self.read_position()
         self.logger.info(f"Movement ended. New position = {self.output['Position']}")
-        self.gui.set_non_moving_state
+        self.gui.set_non_moving_state()
 
     def read_stage_info(self):
         #From the thorlabs_APT code:
@@ -216,8 +225,9 @@ class interface(abstract_instrument_interface.abstract_interface):
         self.logger.info(f"Moving to {position}...")
         self.instrument.position = position
         self.gui.set_moving_state()
-        self.wait_until_property_is_false(self.instrument,pyThorlabsAPT.is_in_motion,[self.end_movement])
-        self.wait_until_property_is_false(self.instrument,pyThorlabsAPT.is_in_motion,[self.gui.set_non_moving_state])
+        #Start checking periodically the value of self.instrument.is_in_motion. It it's true, we read current
+        #position and update it in the GUI. When it becomes False, call self.end_movement
+        self.check_property_until(self.instrument,pyThorlabsAPT.is_in_motion,[True,False],[[self.read_position],[self.end_movement]])
         
     def start_ramp(self,initial_trigger, stepsize, wait1, wait2, numb_steps, add_reverse = False, repeat_ramp=1):
         ###TO ADD: sanity check on input parameters
@@ -338,12 +348,13 @@ class gui(abstract_instrument_interface.abstract_gui):
         self.label_By  = Qt.QLabel("By ")
         self.edit_StepSize = Qt.QLineEdit()
         self.edit_StepSize.setToolTip('')
-        for w in [self.button_ConnectDevice,self.label_Position,self.edit_Position,self.label_Move,self.button_MoveNegative,self.button_MovePositive,self.label_By,self.edit_StepSize]:
+        self.button_Home = Qt.QPushButton("Home")
+        for w in [self.button_ConnectDevice,self.label_Position,self.edit_Position,self.label_Move,self.button_MoveNegative,self.button_MovePositive,self.label_By,self.edit_StepSize,self.button_Home]:
             hbox2.addWidget(w)
 
         #min_pos, max_pos, units, pitch
         stageparams_groupbox = Qt.QGroupBox()
-        stageparams_groupbox.setTitle(f"Stage Parameters")
+        stageparams_groupbox.setTitle(f"Stage Parameters [ONLY CHANGE THESE IF YOU KNOW WHAT YOU ARE DOING]")
         stageparams_hbox = Qt.QHBoxLayout()
         self.label_min_pos = Qt.QLabel("Min Pos: ")
         self.edit_min_pos = Qt.QLineEdit()
@@ -410,7 +421,7 @@ class gui(abstract_instrument_interface.abstract_gui):
         self.container.addStretch(1)
         
         self.widgets_disabled_when_doing_ramp = [self.button_ConnectDevice,self.combo_Devices,
-                                                 self.label_Position,self.edit_Position,
+                                                 self.label_Position,self.edit_Position,self.button_Home,
                                                  self.label_min_pos,self.edit_min_pos,self.label_max_pos,self.edit_max_pos,self.label_units,self.combo_units,self.label_pitch,self.edit_pitch,self.button_set_stageparams,
                                                self.label_Move,self.button_MoveNegative,self.button_MovePositive,self.label_By,self.edit_StepSize,
                                                self.checkbox_Initial_trigger,self.label_Move_ramp,self.edit_StepSize_ramp,self.label_Wait1_ramp,self.edit_Wait1_ramp,self.label_Wait2_ramp,
@@ -418,7 +429,7 @@ class gui(abstract_instrument_interface.abstract_gui):
                                                self.checkbox_Reverse,self.label_Ramp_repeat,self.spinbox_Ramp_repeat,self.label_Ramp_repeat2]
 
         self.widgets_enabled_when_connected = [self.combo_Devices , self.button_RefreshDeviceList,
-                                               self.label_Position, self.edit_Position,
+                                               self.label_Position, self.edit_Position,self.button_Home,
                                                self.label_min_pos,self.edit_min_pos,self.label_max_pos,self.edit_max_pos,self.label_units,self.combo_units,self.label_pitch,self.edit_pitch,self.button_set_stageparams,
                                                self.label_Move,self.button_MoveNegative,self.button_MovePositive,self.label_By,self.edit_StepSize,
                                                self.checkbox_Initial_trigger,self.label_Move_ramp,self.edit_StepSize_ramp,self.label_Wait1_ramp,self.edit_Wait1_ramp,self.label_Wait2_ramp,
@@ -428,7 +439,7 @@ class gui(abstract_instrument_interface.abstract_gui):
         self.widgets_enabled_when_disconnected = [self.combo_Devices , 
                                                   self.button_RefreshDeviceList]
 
-        self.widgets_disabled_when_moving = [self.button_StartRamp,self.button_set_stageparams,self.button_MoveNegative ,self.button_MovePositive ]
+        self.widgets_disabled_when_moving = [self.button_StartRamp,self.button_set_stageparams,self.button_MoveNegative ,self.button_MovePositive,self.button_Home]
 
     def connect_widgets_events_to_functions(self):
         self.button_RefreshDeviceList.clicked.connect(self.click_button_refresh_list_devices)
@@ -436,6 +447,7 @@ class gui(abstract_instrument_interface.abstract_gui):
         self.edit_Position.returnPressed.connect(self.press_enter_edit_Position)
         self.button_MoveNegative.clicked.connect(lambda x:self.click_button_Move(-1))
         self.button_MovePositive.clicked.connect(lambda x:self.click_button_Move(+1))
+        self.button_Home.clicked.connect(self.click_button_Home)
         self.edit_StepSize.returnPressed.connect(self.press_enter_edit_StepSize)
         self.button_set_stageparams .clicked.connect(self.click_button_set_stageparams)
         self.button_StartRamp.clicked.connect(self.click_button_start_ramp)
@@ -511,6 +523,9 @@ class gui(abstract_instrument_interface.abstract_gui):
     def click_button_Move(self,direction):
         self.press_enter_edit_StepSize()
         self.interface.move_single_step(direction)
+        
+    def click_button_Home(self):
+        self.interface.home()
 
     def click_button_set_stageparams(self):
             self.interface.set_stage_info( min_pos =   self.edit_min_pos.text(),
